=====================================================================
Yeast Pathway Kit Assembly Report
=====================================================================

Yeast pathway kit assembly 2014-05-15 13:54:58:

`pYPK0_TEF1tp_SsXYL1_TDH3tp_SsXYL2_PGItp_pw <./pYPK0_TEF1tp_SsXYL1_TDH3tp_SsXYL2_PGItp_pw.txt>`_
(`plan <./pYPK0_TEF1tp_SsXYL1_TDH3tp_SsXYL2_PGItp_pw_plan.html>`__)

List of all `PCR primers <./primer_list.txt>`_ needed
  

`pYPK0_TEF1tp_SsXYL1_TDH3tp <./pYPK0_TEF1tp_SsXYL1_TDH3tp.txt>`_ (`plan <./pYPK0_TEF1tp_SsXYL1_TDH3tp_plan.html>`__)

	 * `pYPKa_Z_TEF1tp <./pYPKa_Z_TEF1tp.txt>`_ (`plan <./pYPKa_Z_TEF1tp_plan.html>`__)
	 * `pYPKa_A_SsXYL1 <./pYPKa_A_SsXYL1.txt>`_ (`plan <./pYPKa_A_SsXYL1_plan.html>`__)
	 * `pYPKa_E_TDH3tp <./pYPKa_E_TDH3tp.txt>`_ (`plan <./pYPKa_E_TDH3tp_plan.html>`__)

`pYPK0_TDH3tp_SsXYL2_PGItp <./pYPK0_TDH3tp_SsXYL2_PGItp.txt>`_ (`plan <./pYPK0_TDH3tp_SsXYL2_PGItp_plan.html>`__)

	 * `pYPKa_Z_TDH3tp <./pYPKa_Z_TDH3tp.txt>`_ (`plan <./pYPKa_Z_TDH3tp_plan.html>`__)
	 * `pYPKa_A_SsXYL2 <./pYPKa_A_SsXYL2.txt>`_ (`plan <./pYPKa_A_SsXYL2_plan.html>`__)
	 * `pYPKa_E_PGItp <./pYPKa_E_PGItp.txt>`_ (`plan <./pYPKa_E_PGItp_plan.html>`__)

